@@ -4,6 +4,7 @@
  *   SPDX-FileCopyrightText: 2008-2010 Matthias Fuchs <mat69@gmx.net>
  *   SPDX-FileCopyrightText: 2012 Reza Fatahilah Shah <rshah0385@kireihana.com>
  *   SPDX-FileCopyrightText: 2015 Marco Martin <mart@kde.org>
+ *   SPDX-FileCopyrightText: 2022 Alexander Lohnau <alexander.lohnau@gmx.de>
  *
  *   SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -11,16 +12,17 @@
 #ifndef COMIC_H
 #define COMIC_H
 
-#include "comicdata.h"
-
 #include <QDate>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#include <QNetworkConfigurationManager>
+#endif
 #include <QUrl>
 
 #include <Plasma/Applet>
-#include <Plasma/DataEngine>
-#include <Plasma/DataEngineConsumer>
 
 #include "activecomicmodel.h"
+#include "comicdata.h"
+#include "engine/comic.h"
 
 class CheckNewStrips;
 class ComicModel;
@@ -32,7 +34,7 @@ class QSortFilterProxyModel;
 class QTimer;
 class SavingDir;
 
-class ComicApplet : public Plasma::Applet, public Plasma::DataEngineConsumer
+class ComicApplet : public Plasma::Applet
 {
     Q_OBJECT
     Q_PROPERTY(QObject *comicsModel READ comicsModel NOTIFY comicModelChanged)
@@ -52,7 +54,7 @@ class ComicApplet : public Plasma::Applet, public Plasma::DataEngineConsumer
     Q_PROPERTY(int maxComicLimit READ maxComicLimit WRITE setMaxComicLimit NOTIFY maxComicLimitChanged)
 
 public:
-    ComicApplet(QObject *parent, const QVariantList &args);
+    ComicApplet(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
     ~ComicApplet() override;
 
     void init() override;
@@ -118,9 +120,6 @@ Q_SIGNALS:
     void providerUpdateIntervalChanged();
     void maxComicLimitChanged();
 
-public Q_SLOTS:
-    void dataUpdated(const QString &name, const Plasma::DataEngine::Data &data);
-
 private Q_SLOTS:
     void slotTabChanged(const QString &newIdentifier);
     void slotNextDay();
@@ -158,7 +157,10 @@ public Q_SLOTS:
         slotTabChanged(newIdentifier);
     }
 
-    Q_INVOKABLE void loadProviders();
+    Q_INVOKABLE void loadProviders()
+    {
+        mEngine->loadProviders();
+    }
     Q_INVOKABLE void positionFullView(QWindow *window);
 
 private:
@@ -169,10 +171,17 @@ private:
     void refreshComicData();
     void setTabHighlighted(const QString &id, bool highlight);
     bool isTabHighlighted(const QString &id) const;
+    void dataUpdated(const ComicMetaData &data);
 
 private:
-    static const int CACHE_LIMIT;
     ComicModel *mModel;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    QT_WARNING_PUSH
+    QT_WARNING_DISABLE_DEPRECATED
+    QNetworkConfigurationManager m_networkConfigurationManager;
+    QT_WARNING_POP
+#endif
+    QString mPreviousFailedIdentifier;
     QSortFilterProxyModel *mProxy;
     ActiveComicModel *mActiveComicModel;
     QVariantMap mComicData;
@@ -207,7 +216,7 @@ private:
     QSizeF mMaxSize;
     QSizeF mLastSize;
     QSizeF mIdealSize;
-    Plasma::DataEngine *mEngine;
+    ComicEngine *const mEngine;
 
     // Tabs
     bool mTabAdded;
