@@ -8,9 +8,10 @@
 #define COMIC_DATA_H
 
 #include "comicinfo.h"
+#include "engine/types.h"
 
-#include <Plasma/DataEngine>
 // Qt
+#include <KConfigGroup>
 #include <QImage>
 #include <QString>
 #include <QUrl>
@@ -22,7 +23,7 @@ public:
 
     void init(const QString &id, const KConfigGroup &config);
 
-    void setData(const Plasma::DataEngine::Data &data);
+    void setData(const ComicMetaData &data);
 
     IdentifierType type() const
     {
@@ -190,16 +191,11 @@ public:
         return mMaxStripNum;
     }
 
-    bool ready() const
-    {
-        return mReady;
-    }
-
     void save();
 
 private:
     void load();
-    void createErrorPicture(const Plasma::DataEngine::Data &data);
+    void createErrorPicture(const QVariantMap &data);
 
 private:
     IdentifierType mType;
@@ -231,7 +227,6 @@ private:
     bool mScaleComic = false;
     bool mIsLeftToRight = false;
     bool mIsTopToBottom = false;
-    bool mReady = false;
 
     KConfigGroup mCfg;
 };
