@@ -18,16 +18,16 @@ static const QString dateWord = i18nc("Note this is a KRunner keyword", "date");
 static const QString timeWord = i18nc("Note this is a KRunner keyword", "time");
 
 DateTimeRunner::DateTimeRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
-    : Plasma::AbstractRunner(parent, metaData, args)
+    : AbstractRunner(parent, metaData, args)
 {
     setObjectName(QLatin1String("DataTimeRunner"));
 
-    addSyntax(Plasma::RunnerSyntax(dateWord, i18n("Displays the current date")));
-    addSyntax(Plasma::RunnerSyntax(timeWord, i18n("Displays the current time")));
-    addSyntax(Plasma::RunnerSyntax(dateWord + i18nc("The <> and space are part of the example query", " <timezone>"),
-                                   i18n("Displays the current date in a given timezone")));
-    addSyntax(Plasma::RunnerSyntax(timeWord + i18nc("The <> and space are part of the example query", " <timezone>"),
-                                   i18n("Displays the current time in a given timezone")));
+    addSyntax(RunnerSyntax(dateWord, i18n("Displays the current date")));
+    addSyntax(RunnerSyntax(timeWord, i18n("Displays the current time")));
+    addSyntax(RunnerSyntax(dateWord + i18nc("The <> and space are part of the example query", " <timezone>"), //
+                           i18n("Displays the current date in a given timezone")));
+    addSyntax(RunnerSyntax(timeWord + i18nc("The <> and space are part of the example query", " <timezone>"), //
+                           i18n("Displays the current time in a given timezone")));
     setTriggerWords({timeWord, dateWord});
 }
 
@@ -35,14 +35,18 @@ DateTimeRunner::~DateTimeRunner()
 {
 }
 
-void DateTimeRunner::match(Plasma::RunnerContext &context)
+void DateTimeRunner::match(RunnerContext &context)
 {
     const QString term = context.query();
     if (term.compare(dateWord, Qt::CaseInsensitive) == 0) {
         const QString date = QLocale().toString(QDate::currentDate());
         addMatch(i18n("Today's date is %1", date), date, context, QStringLiteral("view-calendar-day"));
     } else if (term.startsWith(dateWord + QLatin1Char(' '), Qt::CaseInsensitive)) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const auto tz = term.rightRef(term.length() - dateWord.length() - 1);
+#else
+        const auto tz = QStringView(term).right(term.length() - dateWord.length() - 1);
+#endif
         const auto dates = datetime(tz);
         for (auto it = dates.constBegin(), itEnd = dates.constEnd(); it != itEnd; ++it) {
             const QString date = QLocale().toString(*it);
@@ -52,7 +56,11 @@ void DateTimeRunner::match(Plasma::RunnerContext &context)
         const QString time = QLocale().toString(QTime::currentTime());
         addMatch(i18n("Current time is %1", time), time, context, QStringLiteral("clock"));
     } else if (term.startsWith(timeWord + QLatin1Char(' '), Qt::CaseInsensitive)) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const auto tz = term.rightRef(term.length() - timeWord.length() - 1);
+#else
+        const auto tz = QStringView(term).right(term.length() - timeWord.length() - 1);
+#endif
         const auto times = datetime(tz);
         for (auto it = times.constBegin(), itEnd = times.constEnd(); it != itEnd; ++it) {
             const QString time = QLocale().toString(*it, QLocale::ShortFormat);
@@ -60,8 +68,11 @@ void DateTimeRunner::match(Plasma::RunnerContext &context)
         }
     }
 }
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 QHash<QString, QDateTime> DateTimeRunner::datetime(const QStringRef &tz)
+#else
+QHash<QString, QDateTime> DateTimeRunner::datetime(const QStringView &tz)
+#endif
 {
     QHash<QString, QDateTime> ret;
     //
@@ -104,12 +115,12 @@ QHash<QString, QDateTime> DateTimeRunner::datetime(const QStringRef &tz)
     return ret;
 }
 
-void DateTimeRunner::addMatch(const QString &text, const QString &clipboardText, Plasma::RunnerContext &context, const QString &iconName)
+void DateTimeRunner::addMatch(const QString &text, const QString &clipboardText, RunnerContext &context, const QString &iconName)
 {
-    Plasma::QueryMatch match(this);
+    QueryMatch match(this);
     match.setText(text);
     match.setData(clipboardText);
-    match.setType(Plasma::QueryMatch::InformationalMatch);
+    match.setType(QueryMatch::InformationalMatch);
     match.setIconName(iconName);
 
     context.addMatch(match);
