@@ -6,26 +6,23 @@
 #ifndef DICTIONARYRUNNER_H
 #define DICTIONARYRUNNER_H
 
-#include "dictionarymatchengine.h"
+#include "../../dict/dictengine.h"
 #include <KRunner/AbstractRunner>
-#include <Plasma/DataEngineConsumer>
 
-class DictionaryRunner : public Plasma::AbstractRunner
+using namespace Plasma;
+
+class DictionaryRunner : public AbstractRunner
 {
     Q_OBJECT
 
 public:
     explicit DictionaryRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
-    void match(Plasma::RunnerContext &context) override;
+    void match(RunnerContext &context) override;
     void reloadConfiguration() override;
 
 private:
     QString m_triggerWord;
-    DictionaryMatchEngine *m_engine;
-    Plasma::DataEngineConsumer m_consumer;
-
-protected Q_SLOTS:
-    void init() override;
+    DictEngine m_dictEngine;
 };
 
 #endif
